-- Frame:SetBackdropColor
-- AddOn initialization

local options = { 
    type='group',
    args = {
        checkInterval = {
            type = 'range',
            name = 'check interval',
            desc = 'Set the interval in which GoodTarget checks the targets target (in seconds).',
            min = 0.01,
            max = 1.0,
            step = 0.01,
            bigStep = 0.02,
            get = "GetCheckInterval",
            set = "SetCheckInterval",
        },
        scale = {
            type = 'range',
            name = 'scale',
            desc = 'Set the scale of the frame.',
            min = 0.1,
            max = 4.0,
            step = 0.01,
            bigStep = 0.1,
            get = "GetScale",
            set = "SetScale",
        },
        width = {
            type = 'range',
            name = 'width',
            desc = 'Set the width of the frame.',
            min = 10,
            max = 500,
            step = 1,
            bigStep = 1,
            get = "GetWidth",
            set = "SetWidth",
        },
        playSound = {
            type = 'toggle',
            name = 'sound',
            desc = 'Enables or disables sounds.',
            get = "IsSoundOn",
            set = "SetSoundOnOf",
        },
        isLocked = {
            type = 'toggle',
            name = 'lock',
            desc = 'Locks or unlocks the frame.',
            get = "IsLocked",
            set = "SetLocked",
        },
    },
}


GoodTarget = AceLibrary("AceAddon-2.0"):new("AceConsole-2.0", "AceEvent-2.0", "AceDB-2.0")
GoodTarget:RegisterChatCommand("/goodtarget", "/gt", options)

GoodTarget:RegisterDB("GoodTargetDB", "GoodTargetDBPC")
GoodTarget:RegisterDefaults("profile", {
    CheckInterval = 0.05,
    PlaySound = true,
    isLocked = false,
    Scale = 1.0,
    Width = 100,
} )



function GoodTarget:Update()
    if(UnitIsFriend("player", "playertarget")) then -- only check for hostile targets
        self:SetNoneTarget();
        self.LastTT = nil;
        return;
    end
    
	if(UnitIsUnit("player", "playertargettarget")) then --targets target is the player        
		self:SetGoodTarget()
    elseif(UnitExists("playertargettarget")) then --targets target is not the player
		self:SetBadTarget();		
	elseif((not UnitExists("playertargettarget"))) then --there is no targets target
		self:SetNoneTarget();		
	end
end

function GoodTarget.FrameOnMouseDown(f, button)
    if not f.isLocked and button == "LeftButton" then
		f:StartMoving()
	end
end

function GoodTarget.FrameOnMouseUp(f)
    f:StopMovingOrSizing()
end

function GoodTarget:OnInitialize()
    local f=CreateFrame("FRAME","GoodTarget_Frame",UIParent);
    self.frame = f
    
    f:SetMovable(true)
    f:SetResizable(true)
    f:EnableMouse(true)
    
    f:SetWidth(self.db.profile.Width); 
    f:SetHeight(10);
    
    f:SetScale(self.db.profile.Scale);
    f:SetPoint("CENTER",UIParent);
    f:SetBackdrop({
      bgFile="Interface\\Tooltips\\UI-Tooltip-Background", 
      tile=1, tileSize=10, edgeSize=0, 
      insets={left=0, right=0, top=0, bottom=0}
    });
    f:SetBackdropColor(0.0, 0.0, 0.0, 0.0)
    
    f:SetScript("OnMouseUp", GoodTarget.FrameOnMouseUp)
	f:SetScript("OnMouseDown", GoodTarget.FrameOnMouseDown)
    
    f.target = f:CreateFontString("$parentText","ARTWORK","GameFontNormal");
    f.target:SetAllPoints()
    
    f.isLocked = self.db.profile.isLocked
    
    
end
    
function GoodTarget:OnEnable()
    -- Called when the addon is enabled
    self:RegisterEvent("PLAYER_TARGET_CHANGED")
    self:ScheduleRepeatingEvent("CheckTargetTarget", "checkTarget", self.db.profile.CheckInterval)    
    self:RegisterEvent("checkTarget")
    self.frame:Show()
end

function GoodTarget:checkTarget()
    self:Update()
end

function GoodTarget:OnDisable()
    self.frame:Hide()
end

function GoodTarget:IsSoundOn()
    return self.db.profile.PlaySound
end

function GoodTarget:SetSoundOnOf(isOn)
    self.db.profile.PlaySound = isOn
end

function GoodTarget:IsLocked()
    return self.db.profile.isLocked
end

function GoodTarget:SetLocked(isLocked)
    self.db.profile.isLocked = isLocked
    self.frame.isLocked = self.db.profile.isLocked
end

function GoodTarget:GetScale()
    return self.db.profile.scale
end

function GoodTarget:SetScale(scale)
    self.db.profile.Scale = scale
    self.frame:SetScale(scale)
end

function GoodTarget:GetWidth()
    return self.db.profile.Width
end

function GoodTarget:SetWidth(width)
    self.db.profile.Width = width
    self.frame:SetWidth(width)
end

function GoodTarget:GetCheckInterval()
    return self.db.profile.CheckInterval
end

function GoodTarget:SetCheckInterval(interval)
    self.db.profile.CheckInterval = interval
    self:CancelScheduledEvent("CheckTargetTarget")
    self:Update()
    self:ScheduleRepeatingEvent("CheckTargetTarget", "checkTarget", self.db.profile.CheckInterval)
end

function GoodTarget:PLAYER_TARGET_CHANGED()
    self:Update();
end

function GoodTarget:SetGoodTarget() -- set GoodTarget frame to good an play good sound
    if(self.LastTT ~= "player") then
        if self.db.profile.PlaySound and self.LastTT then PlaySoundFile("Sound\\interface\\AuctionWindowOpen.wav") end;
        self.frame.target:SetTextColor(1,1,1,1);
        self.frame.target:SetText("Good");
        self.frame:SetBackdropColor(0.0, 1.0, 0.0, 1.0)
        self.LastTT = "player";
    end
end

function GoodTarget:SetBadTarget() -- set GoodTarget frame to bad an play bad sound
    --self:Print("BT")
    if(self.LastTT == "player" or not self.LastTT) then
        if(self.db.profile.PlaySound) then PlaySoundFile("Sound\\Creature\\Cannon\\CannonDeath.wav") end;
    end
    if(self.LastTT ~= UnitName("playertargettarget")) then 
        self.frame.target:SetTextColor(1,1,01,1);
        self.frame:SetBackdropColor(1.0, 0.0, 0.0, 1.0)
        self.frame.target:SetText(UnitName("playertargettarget"));
        self.LastTT = UnitName("playertargettarget");
    end
end

function GoodTarget:SetNoneTarget() -- clear GoodTarget frame
    if(self.LastTT ~= nil) then
        self.frame.target:SetTextColor(0.5,0.5,0.5,1);
        self.frame:SetBackdropColor(0.0, 0.0, 0.0, 0.0)
        self.frame.target:SetText("");
        self.LastTT = nil;
    end
end




